# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr
from pydantic import Field
from sailpoint.beta.models.role_mining_identity_distribution import RoleMiningIdentityDistribution
from sailpoint.beta.models.role_mining_potential_role_provision_state import RoleMiningPotentialRoleProvisionState
from sailpoint.beta.models.role_mining_role_type import RoleMiningRoleType
from sailpoint.beta.models.role_mining_session_parameters_dto import RoleMiningSessionParametersDto
from sailpoint.beta.models.role_mining_session_response_created_by import RoleMiningSessionResponseCreatedBy
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class RoleMiningPotentialRole(BaseModel):
    """
    RoleMiningPotentialRole
    """ # noqa: E501
    created_by: Optional[RoleMiningSessionResponseCreatedBy] = Field(default=None, alias="createdBy")
    density: Optional[StrictInt] = Field(default=None, description="The density of a potential role.")
    description: Optional[StrictStr] = Field(default=None, description="The description of a potential role.")
    entitlement_count: Optional[StrictInt] = Field(default=None, description="The number of entitlements in a potential role.", alias="entitlementCount")
    excluded_entitlements: Optional[List[StrictStr]] = Field(default=None, description="The list of entitlement ids to be excluded.", alias="excludedEntitlements")
    freshness: Optional[StrictInt] = Field(default=None, description="The freshness of a potential role.")
    identity_count: Optional[StrictInt] = Field(default=None, description="The number of identities in a potential role.", alias="identityCount")
    identity_distribution: Optional[List[RoleMiningIdentityDistribution]] = Field(default=None, description="Identity attribute distribution.", alias="identityDistribution")
    identity_ids: Optional[List[StrictStr]] = Field(default=None, description="The list of ids in a potential role.", alias="identityIds")
    name: Optional[StrictStr] = Field(default=None, description="Name of the potential role.")
    provision_state: Optional[RoleMiningPotentialRoleProvisionState] = Field(default=None, alias="provisionState")
    quality: Optional[StrictInt] = Field(default=None, description="The quality of a potential role.")
    role_id: Optional[StrictStr] = Field(default=None, description="The roleId of a potential role.", alias="roleId")
    saved: Optional[StrictBool] = Field(default=None, description="The potential role's saved status.")
    session: Optional[RoleMiningSessionParametersDto] = None
    type: Optional[RoleMiningRoleType] = None
    id: Optional[StrictStr] = Field(default=None, description="Id of the potential role")
    created_date: Optional[datetime] = Field(default=None, description="The date-time when this potential role was created.", alias="createdDate")
    modified_date: Optional[datetime] = Field(default=None, description="The date-time when this potential role was modified.", alias="modifiedDate")
    __properties: ClassVar[List[str]] = ["createdBy", "density", "description", "entitlementCount", "excludedEntitlements", "freshness", "identityCount", "identityDistribution", "identityIds", "name", "provisionState", "quality", "roleId", "saved", "session", "type", "id", "createdDate", "modifiedDate"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RoleMiningPotentialRole from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['createdBy'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in identity_distribution (list)
        _items = []
        if self.identity_distribution:
            for _item in self.identity_distribution:
                if _item:
                    _items.append(_item.to_dict())
            _dict['identityDistribution'] = _items
        # override the default output from pydantic by calling `to_dict()` of session
        if self.session:
            _dict['session'] = self.session.to_dict()
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if excluded_entitlements (nullable) is None
        # and model_fields_set contains the field
        if self.excluded_entitlements is None and "excluded_entitlements" in self.model_fields_set:
            _dict['excludedEntitlements'] = None

        # set to None if identity_distribution (nullable) is None
        # and model_fields_set contains the field
        if self.identity_distribution is None and "identity_distribution" in self.model_fields_set:
            _dict['identityDistribution'] = None

        # set to None if role_id (nullable) is None
        # and model_fields_set contains the field
        if self.role_id is None and "role_id" in self.model_fields_set:
            _dict['roleId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of RoleMiningPotentialRole from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "createdBy": RoleMiningSessionResponseCreatedBy.from_dict(obj.get("createdBy")) if obj.get("createdBy") is not None else None,
            "density": obj.get("density"),
            "description": obj.get("description"),
            "entitlementCount": obj.get("entitlementCount"),
            "excludedEntitlements": obj.get("excludedEntitlements"),
            "freshness": obj.get("freshness"),
            "identityCount": obj.get("identityCount"),
            "identityDistribution": [RoleMiningIdentityDistribution.from_dict(_item) for _item in obj.get("identityDistribution")] if obj.get("identityDistribution") is not None else None,
            "identityIds": obj.get("identityIds"),
            "name": obj.get("name"),
            "provisionState": obj.get("provisionState"),
            "quality": obj.get("quality"),
            "roleId": obj.get("roleId"),
            "saved": obj.get("saved"),
            "session": RoleMiningSessionParametersDto.from_dict(obj.get("session")) if obj.get("session") is not None else None,
            "type": obj.get("type"),
            "id": obj.get("id"),
            "createdDate": obj.get("createdDate"),
            "modifiedDate": obj.get("modifiedDate")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
import re  # noqa: F401
from enum import Enum



try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class RequestableObjectRequestStatus(str, Enum):
    """
    Status indicating the ability of an access request for the object to be made by or on behalf of the identity specified by *identity-id*. *AVAILABLE* indicates the object is available to request. *PENDING* indicates the object is unavailable because the identity has a pending request in flight. *ASSIGNED* indicates the object is unavailable because the identity already has the indicated role or access profile. If *identity-id* is not specified (allowed only for admin users), then status will be *AVAILABLE* for all results.
    """

    """
    allowed enum values
    """
    AVAILABLE = 'AVAILABLE'
    PENDING = 'PENDING'
    ASSIGNED = 'ASSIGNED'
    NULL = 'null'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RequestableObjectRequestStatus from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.iai_outliers_api import IAIOutliersApi


class TestIAIOutliersApi(unittest.TestCase):
    """IAIOutliersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IAIOutliersApi()

    def tearDown(self) -> None:
        pass

    def test_export_outliers_zip(self) -> None:
        """Test case for export_outliers_zip

        IAI Identity Outliers Export
        """
        pass

    def test_get_identity_outlier_snapshots(self) -> None:
        """Test case for get_identity_outlier_snapshots

        IAI Identity Outliers Summary
        """
        pass

    def test_get_identity_outliers(self) -> None:
        """Test case for get_identity_outliers

        IAI Get Identity Outliers
        """
        pass

    def test_get_latest_identity_outlier_snapshots(self) -> None:
        """Test case for get_latest_identity_outlier_snapshots

        IAI Identity Outliers Latest Summary
        """
        pass

    def test_get_outlier_contributing_feature_summary(self) -> None:
        """Test case for get_outlier_contributing_feature_summary

        Get identity outlier contibuting feature summary
        """
        pass

    def test_get_peer_group_outliers_contributing_features(self) -> None:
        """Test case for get_peer_group_outliers_contributing_features

        Get identity outlier's contibuting features
        """
        pass

    def test_ignore_identity_outliers(self) -> None:
        """Test case for ignore_identity_outliers

        IAI Identity Outliers Ignore
        """
        pass

    def test_list_outliers_contributing_feature_access_items(self) -> None:
        """Test case for list_outliers_contributing_feature_access_items

        Gets a list of access items associated with each identity outlier contributing feature
        """
        pass

    def test_un_ignore_identity_outliers(self) -> None:
        """Test case for un_ignore_identity_outliers

        IAI Identity Outliers Unignore
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from sailpoint.beta.models.cancelable_account_activity import CancelableAccountActivity

class TestCancelableAccountActivity(unittest.TestCase):
    """CancelableAccountActivity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CancelableAccountActivity:
        """Test CancelableAccountActivity
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CancelableAccountActivity`
        """
        model = CancelableAccountActivity()
        if include_optional:
            return CancelableAccountActivity(
                id = '2c9180835d2e5168015d32f890ca1581',
                name = '2c9180835d2e5168015d32f890ca1581',
                created = '2017-07-11T18:45:37.098Z',
                modified = '2018-06-25T20:22:28.104Z',
                completed = '2018-10-19T13:49:37.385Z',
                completion_status = 'SUCCESS',
                type = 'appRequest',
                requester_identity_summary = sailpoint.beta.models.identity_summary.IdentitySummary(
                    id = 'ff80818155fe8c080155fe8d925b0316', 
                    name = 'SailPoint Services', 
                    identity_id = 'c15b9f5cca5a4e9599eaa0e64fa921bd', 
                    completed = True, ),
                target_identity_summary = sailpoint.beta.models.identity_summary.IdentitySummary(
                    id = 'ff80818155fe8c080155fe8d925b0316', 
                    name = 'SailPoint Services', 
                    identity_id = 'c15b9f5cca5a4e9599eaa0e64fa921bd', 
                    completed = True, ),
                errors = [sailpoint.connector.ConnectorException: java.lang.InterruptedException: Timeout waiting for response to message 0 from client 57a4ab97-ab3f-4aef-9fe2-0eaf15c73d26 after 60 seconds.],
                warnings = [
                    ''
                    ],
                items = [
                    sailpoint.beta.models.account_activity_item.AccountActivityItem(
                        id = '48c545831b264409a81befcabb0e3c5a', 
                        name = '48c545831b264409a81befcabb0e3c5a', 
                        requested = '2017-07-11T18:45:37.098Z', 
                        approval_status = null, 
                        provisioning_status = 'PENDING', 
                        requester_comment = sailpoint.beta.models.comment.Comment(
                            commenter_id = '2c918084660f45d6016617daa9210584', 
                            commenter_name = 'Adam Kennedy', 
                            body = 'Et quam massa maximus vivamus nisi ut urna tincidunt metus elementum erat.', 
                            date = '2017-07-11T18:45:37.098Z', ), 
                        reviewer_identity_summary = sailpoint.beta.models.identity_summary.IdentitySummary(
                            id = 'ff80818155fe8c080155fe8d925b0316', 
                            name = 'SailPoint Services', 
                            identity_id = 'c15b9f5cca5a4e9599eaa0e64fa921bd', 
                            completed = True, ), 
                        reviewer_comment = sailpoint.beta.models.comment.Comment(
                            commenter_id = '2c918084660f45d6016617daa9210584', 
                            commenter_name = 'Adam Kennedy', 
                            body = 'Et quam massa maximus vivamus nisi ut urna tincidunt metus elementum erat.', 
                            date = '2017-07-11T18:45:37.098Z', ), 
                        operation = null, 
                        attribute = 'detectedRoles', 
                        value = 'Treasury Analyst [AccessProfile-1529010191212]', 
                        native_identity = 'Sandie.Camero', 
                        source_id = '2c91808363ef85290164000587130c0c', 
                        account_request_info = sailpoint.beta.models.account_request_info.AccountRequestInfo(
                            requested_object_id = '2c91808563ef85690164001c31140c0c', 
                            requested_object_name = 'Treasury Analyst', 
                            requested_object_type = 'ACCESS_PROFILE', ), 
                        client_metadata = {customKey1=custom value 1, customKey2=custom value 2}, 
                        remove_date = '2020-07-11T00:00Z', )
                    ],
                execution_status = 'COMPLETED',
                client_metadata = {
                    'key' : ''
                    },
                cancelable = True,
                cancel_comment = sailpoint.beta.models.comment.Comment(
                    commenter_id = '2c918084660f45d6016617daa9210584', 
                    commenter_name = 'Adam Kennedy', 
                    body = 'Et quam massa maximus vivamus nisi ut urna tincidunt metus elementum erat.', 
                    date = '2017-07-11T18:45:37.098Z', )
            )
        else:
            return CancelableAccountActivity(
        )
        """

    def testCancelableAccountActivity(self):
        """Test CancelableAccountActivity"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from sailpoint.v3.models.schedule1_days import Schedule1Days
from sailpoint.v3.models.schedule1_hours import Schedule1Hours
from sailpoint.v3.models.schedule1_months import Schedule1Months
from sailpoint.v3.models.schedule_type import ScheduleType
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class Schedule1(BaseModel):
    """
    The schedule information.
    """ # noqa: E501
    type: ScheduleType
    months: Optional[Schedule1Months] = None
    days: Optional[Schedule1Days] = None
    hours: Schedule1Hours
    expiration: Optional[datetime] = Field(default=None, description="A date-time in ISO-8601 format")
    time_zone_id: Optional[StrictStr] = Field(default=None, description="The canonical TZ identifier the schedule will run in (ex. America/New_York).  If no timezone is specified, the org's default timezone is used.", alias="timeZoneId")
    __properties: ClassVar[List[str]] = ["type", "months", "days", "hours", "expiration", "timeZoneId"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Schedule1 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of months
        if self.months:
            _dict['months'] = self.months.to_dict()
        # override the default output from pydantic by calling `to_dict()` of days
        if self.days:
            _dict['days'] = self.days.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hours
        if self.hours:
            _dict['hours'] = self.hours.to_dict()
        # set to None if expiration (nullable) is None
        # and model_fields_set contains the field
        if self.expiration is None and "expiration" in self.model_fields_set:
            _dict['expiration'] = None

        # set to None if time_zone_id (nullable) is None
        # and model_fields_set contains the field
        if self.time_zone_id is None and "time_zone_id" in self.model_fields_set:
            _dict['timeZoneId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of Schedule1 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "months": Schedule1Months.from_dict(obj.get("months")) if obj.get("months") is not None else None,
            "days": Schedule1Days.from_dict(obj.get("days")) if obj.get("days") is not None else None,
            "hours": Schedule1Hours.from_dict(obj.get("hours")) if obj.get("hours") is not None else None,
            "expiration": obj.get("expiration"),
            "timeZoneId": obj.get("timeZoneId")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictInt
from pydantic import Field
from typing_extensions import Annotated
from sailpoint.beta.models.identity_reference_with_name_and_email import IdentityReferenceWithNameAndEmail
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class ApprovalReminderAndEscalationConfig(BaseModel):
    """
    ApprovalReminderAndEscalationConfig
    """ # noqa: E501
    days_until_escalation: Optional[StrictInt] = Field(default=None, description="Number of days to wait before the first reminder. If no reminders are configured, then this is the number of days to wait before escalation.", alias="daysUntilEscalation")
    days_between_reminders: Optional[StrictInt] = Field(default=None, description="Number of days to wait between reminder notifications.", alias="daysBetweenReminders")
    max_reminders: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Maximum number of reminder notification to send to the reviewer before approval escalation.", alias="maxReminders")
    fallback_approver_ref: Optional[IdentityReferenceWithNameAndEmail] = Field(default=None, alias="fallbackApproverRef")
    __properties: ClassVar[List[str]] = ["daysUntilEscalation", "daysBetweenReminders", "maxReminders", "fallbackApproverRef"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ApprovalReminderAndEscalationConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of fallback_approver_ref
        if self.fallback_approver_ref:
            _dict['fallbackApproverRef'] = self.fallback_approver_ref.to_dict()
        # set to None if days_until_escalation (nullable) is None
        # and model_fields_set contains the field
        if self.days_until_escalation is None and "days_until_escalation" in self.model_fields_set:
            _dict['daysUntilEscalation'] = None

        # set to None if days_between_reminders (nullable) is None
        # and model_fields_set contains the field
        if self.days_between_reminders is None and "days_between_reminders" in self.model_fields_set:
            _dict['daysBetweenReminders'] = None

        # set to None if max_reminders (nullable) is None
        # and model_fields_set contains the field
        if self.max_reminders is None and "max_reminders" in self.model_fields_set:
            _dict['maxReminders'] = None

        # set to None if fallback_approver_ref (nullable) is None
        # and model_fields_set contains the field
        if self.fallback_approver_ref is None and "fallback_approver_ref" in self.model_fields_set:
            _dict['fallbackApproverRef'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of ApprovalReminderAndEscalationConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "daysUntilEscalation": obj.get("daysUntilEscalation"),
            "daysBetweenReminders": obj.get("daysBetweenReminders"),
            "maxReminders": obj.get("maxReminders"),
            "fallbackApproverRef": IdentityReferenceWithNameAndEmail.from_dict(obj.get("fallbackApproverRef")) if obj.get("fallbackApproverRef") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.certification_campaign_filters_api import CertificationCampaignFiltersApi


class TestCertificationCampaignFiltersApi(unittest.TestCase):
    """CertificationCampaignFiltersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CertificationCampaignFiltersApi()

    def tearDown(self) -> None:
        pass

    def test_create_campaign_filter(self) -> None:
        """Test case for create_campaign_filter

        Create Campaign Filter
        """
        pass

    def test_delete_campaign_filters(self) -> None:
        """Test case for delete_campaign_filters

        Deletes Campaign Filters
        """
        pass

    def test_get_campaign_filter_by_id(self) -> None:
        """Test case for get_campaign_filter_by_id

        Get Campaign Filter by ID
        """
        pass

    def test_list_campaign_filters(self) -> None:
        """Test case for list_campaign_filters

        List Campaign Filters
        """
        pass

    def test_update_campaign_filter(self) -> None:
        """Test case for update_campaign_filter

        Updates a Campaign Filter
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.governance_groups_api import GovernanceGroupsApi


class TestGovernanceGroupsApi(unittest.TestCase):
    """GovernanceGroupsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GovernanceGroupsApi()

    def tearDown(self) -> None:
        pass

    def test_create_workgroup(self) -> None:
        """Test case for create_workgroup

        Create a new Governance Group.
        """
        pass

    def test_delete_workgroup(self) -> None:
        """Test case for delete_workgroup

        Delete a Governance Group
        """
        pass

    def test_delete_workgroup_members(self) -> None:
        """Test case for delete_workgroup_members

        Remove members from Governance Group
        """
        pass

    def test_delete_workgroups_in_bulk(self) -> None:
        """Test case for delete_workgroups_in_bulk

        Delete Governance Group(s)
        """
        pass

    def test_get_workgroup(self) -> None:
        """Test case for get_workgroup

        Get Governance Group by Id
        """
        pass

    def test_list_connections(self) -> None:
        """Test case for list_connections

        List connections for Governance Group
        """
        pass

    def test_list_workgroup_members(self) -> None:
        """Test case for list_workgroup_members

        List Governance Group Members
        """
        pass

    def test_list_workgroups(self) -> None:
        """Test case for list_workgroups

        List Governance Groups
        """
        pass

    def test_patch_workgroup(self) -> None:
        """Test case for patch_workgroup

        Patch a Governance Group
        """
        pass

    def test_update_workgroup_members(self) -> None:
        """Test case for update_workgroup_members

        Add members to Governance Group
        """
        pass


if __name__ == '__main__':
    unittest.main()
